==> deepin-ocr_1.1.2.tar.xz: BUILD/translations/deepin-ocr_br.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="br">
<context>
    <name>MainWidget</name>
    <message>
        <source>Recognizing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copied</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No text recognized</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save as TXT</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Recognize language</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Simplified Chinese</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>English</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Traditional Chinese</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Undo (Ctrl+Z)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Redo (Ctrl+Shift+Z)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>OCR Tool</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ResultTextView</name>
    <message>
        <source>Copy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Paste</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select All</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Widget</name>
    <message>
        <source>Tips: The clearer the image is, the more accurate the text is</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> deepin-ocr_6.5.7.tar.xz: BUILD/translations/deepin-ocr_br.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="br">
<context>
    <name>MainWidget</name>
    <message>
        <source>Recognizing</source>
        <translation>الإدراك</translation>
    </message>
    <message>
        <source>Copied</source>
        <translation>تم نسخه</translation>
    </message>
    <message>
        <source>No text recognized</source>
        <translation>لا يوجد نص تم إدراكه</translation>
    </message>
    <message>
        <source>Copy text</source>
        <translation>نسخ النص</translation>
    </message>
    <message>
        <source>Save as TXT</source>
        <translation>الحفظ ك TXT</translation>
    </message>
    <message>
        <source>Recognize language</source>
        <translation>تعرف على اللغة</translation>
    </message>
    <message>
        <source>Simplified Chinese</source>
        <translation>الصينية البسيطة</translation>
    </message>
    <message>
        <source>English</source>
        <translation>الإنجليزية</translation>
    </message>
    <message>
        <source>Traditional Chinese</source>
        <translation>الصينية التقليدية</translation>
    </message>
    <message>
        <source>Undo (Ctrl+Z)</source>
        <translation>الاستعادة (Ctrl+Z)</translation>
    </message>
    <message>
        <source>Redo (Ctrl+Shift+Z)</source>
        <translation>إعادة الاستعادة (Ctrl+Shift+Z)</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>OCR Tool</source>
        <translation>أداة التعرف على النص</translation>
    </message>
</context>
<context>
    <name>ResultTextView</name>
    <message>
        <source>Copy</source>
        <translation>نسخ</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>قص</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>لصق</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>اختر كل شيء</translation>
    </message>
</context>
<context>
    <name>Widget</name>
    <message>
        <source>Tips: The clearer the image is, the more accurate the text is</source>
        <translation>نصائح: كلما كانت الصورة أوضح، زادت دقة النص</translation>
    </message>
</context>
</TS>
